__title__ = "cobalt8"
__description__ = "Offline and secure AES encryption with a Discord context in mind. "
__url__ = "https://github.com/8o-COLLECTIVE/cobalt8"
__version__ = "0.0.2"
__author__ = "8o-COLLECTIVE"
__author_email__ = "8ocollective@birdlover.com"
__license__ = "MIT"
__copyright__ = "Copyright 2020-2021 8o Collective"
